@@ -1,18 +1,18 @@
 #' @title Reform any parameter vector into standard form.
 #'
-#' @description \code{reformParameters} takes a parameter vector of any (non-constrained) GMAR, StMAR or G-StMAR model and returns a list with the
-#'  parameter vector in the standard form, parameter matrix containing AR coefficients and component
-#'  variances, mixing weights alphas and in case of StMAR or G-StMAR model also degrees of freedom parameters.
+#' @description \code{reformParameters} takes a parameter vector of any (non-constrained) GMAR, StMAR, or G-StMAR model
+#'  and returns a list with the parameter vector in the standard form, parameter matrix containing AR coefficients and
+#'  component variances, mixing weights alphas, and in case of StMAR or G-StMAR model also degrees of freedom parameters.
 #'
 #' @inheritParams isStationary_int
-#' @details This function does not support models parametrized with general linear constraints! Nor does it have any argument checks.
+#' @details This function does not support models imposing linear constraints. No argument checks in this function.
 #' @return Returns a list with...
 #' \describe{
 #'   \item{\code{$params}}{parameter vector in the standard form.}
 #'   \item{\code{$pars}}{corresponding parameter matrix containing AR coefficients and
 #'     component variances. First row for phi0 or means depending on the parametrization. Column for each component.}
-#'   \item{\code{$alphas}}{numeric vector containing mixing weights for all components (also for the last one).}
-#'   \item{\code{$dfs}}{numeric vector containing degrees of freedom parameters for all components.
+#'   \item{\code{$alphas}}{numeric vector containing mixing weight parameters for all of the components (also for the last one).}
+#'   \item{\code{$dfs}}{numeric vector containing degrees of freedom parameters for all of components.
 #'     Returned only if \code{model == "StMAR"} or \code{model == "G-StMAR"}.}
 #'  }
 
@@ -42,11 +42,7 @@ reformConstrainedPars <- function(p, M, params, model=c("GMAR", "StMAR", "G-StMA
   } else {
     model <- match.arg(model)
     M_orig <- M
-    if(model == "G-StMAR") {
-      M1 <- M[1]
-      M2 <- M[2]
-      M <- sum(M)
-    }
+    M <- sum(M)
     if(restricted == FALSE) {
       params0 <- numeric(0)
       j <- 0
@@ -83,27 +79,26 @@ reformConstrainedPars <- function(p, M, params, model=c("GMAR", "StMAR", "G-StMA
 #' for non-restricted models (for non-constrained models). Linear constraints are not supported.
 
 reformRestrictedPars <- function(p, M, params, model=c("GMAR", "StMAR", "G-StMAR"), restricted=FALSE) {
-  if(restricted == FALSE) return(params)
-  model <- match.arg(model)
-  M_orig <- M
-  if(model == "G-StMAR") {
-    M1 <- M[1]
-    M2 <- M[2]
+  if(restricted == FALSE) {
+    return(params)
+  } else {
+    model <- match.arg(model)
+    M_orig <- M
     M <- sum(M)
+    phi0 <- params[1:M]
+    arcoefs <- matrix(rep(params[(M + 1):(M + p)], M), ncol=M)
+    sigmas <- params[(M + p + 1):(p + 2*M)]
+    pars <- rbind(phi0, arcoefs, sigmas)
+    alphas <- params[(p + 2*M + 1):(3*M + p - 1)]
+    dfs <- pick_dfs(p=p, M=M_orig, params=params, model=model)
+    return(c(as.vector(pars), alphas, dfs))
   }
-  phi0 <- params[1:M]
-  arcoefs <- matrix(rep(params[(M + 1):(M + p)], M), ncol=M)
-  sigmas <- params[(M + p + 1):(p + 2*M)]
-  pars <- rbind(phi0, arcoefs, sigmas)
-  alphas <- params[(p + 2*M + 1):(3*M + p - 1)]
-  dfs <- pick_dfs(p=p, M=M_orig, params=params, model=model)
-  c(as.vector(pars), alphas, dfs)
 }
 
 
 #' @title Transform constrained and restricted parameter vector into the regular form
 #'
-#' @description \code{removeAllConstraints} transforms constraited and restricted parameter vector into the regular form.
+#' @description \code{removeAllConstraints} transforms constrained and restricted parameter vector into the regular form.
 #'
 #' @inheritParams loglikelihood_int
 #' @return Returns such parameter vector corresponding to the input vector that is the form described in \code{params}
@@ -117,15 +112,16 @@ removeAllConstraints <- function(p, M, params, model=c("GMAR", "StMAR", "G-StMAR
 
 
 
-#' @title Sort the mixture components of GMAR, StMAR or G-StMAR model
+#' @title Sort the mixture components of a GMAR, StMAR, or G-StMAR model
 #'
-#' @description \code{sortComponents} sorts mixture components of the specified GMAR, StMAR or G-StMAR model by the mixing weights
-#'   when the parameter vector is in the "standard form" for restricted or non-restricted models.
+#' @description \code{sortComponents} sorts mixture components of the specified GMAR, StMAR, or G-StMAR model
+#'   according to the mixing weight parameters when the parameter vector has the "standard/regular form" for
+#'   restricted or non-restricted models.
 #'
 #' @inheritParams isStationary
-#' @details This function does not support models parametrized with general linear constraints!
-#' @return Returns a parameter vector sorted by it's mixing weights, described in \code{params}.
-#' @details Models with general linear constraints are not supported.
+#' @details This function does not support models imposing linear constraints.
+#' @return Returns a parameter vector sorted according to its mixing weight parameters,
+#'   described in \code{params}.
 
 sortComponents <- function(p, M, params, model=c("GMAR", "StMAR", "G-StMAR"), restricted=FALSE) {
   model <- match.arg(model)
@@ -145,10 +141,10 @@ sortComponents <- function(p, M, params, model=c("GMAR", "StMAR", "G-StMAR"), re
 
     if(restricted == FALSE) {
       return(c(as.vector(pars), alphas[-M], dfs))
-    } else { # If restricted==TRUE
-      return(c(pars[1,], pars[2:(p + 1), 1], pars[p + 2,], alphas[-M], dfs)) # arcoefs <- # params[(M + 1):(M + p)]
+    } else { # If restricted == TRUE
+      return(c(pars[1,], pars[2:(p + 1), 1], pars[p + 2,], alphas[-M], dfs))
     }
-  } else { # If model == "G-StMAR": Sort M1 and M2 components separately - parameter picks are non-standard
+  } else { # If model == "G-StMAR": Sort the M1 and M2 components separately (parameter picks are non-standard)
     M1 <- M[1]
     M2 <- M[2]
     Msum <- sum(M)
@@ -161,14 +157,14 @@ sortComponents <- function(p, M, params, model=c("GMAR", "StMAR", "G-StMAR"), re
         } else {
           pars <- matrix(params[((M1*(p + 2)) + 1):(Msum*(p + 2))], ncol=M2)
         }
-        if(M[i1] > 1) { # If only one component of given type, no need to sort
+        if(M[i1] > 1) { # If only one component of a given type, no need to sort
           if(i1 == 1) {
             alphas <- params[(Msum*(p + 2) + 1):(Msum*(p + 2) + M1)]
           } else {
             alphas <- params[(Msum*(p + 2) + M1 + 1):(Msum*(p + 3) - 1)]
             dfs <- pick_dfs(p=p, M=M, params=params, model=model)
           }
-          if(i1 == 2) { # If i1==2, add the non-parametrized alpha
+          if(i1 == 2) { # If i1 == 2, add the non-parametrized alpha
             alphas <- c(alphas, 1 - (sum(alphas) + sum(alphas0)))
           }
           sortedByAlphas <- order(alphas, decreasing=TRUE)
@@ -183,14 +179,14 @@ sortComponents <- function(p, M, params, model=c("GMAR", "StMAR", "G-StMAR"), re
             alphas <- params[Msum*(p + 2) + 1]
           } else {
             dfs <- params[Msum*(p + 3)]
-            alphas <- numeric(0) # No alphas for StMAR if only one StMAR-component
+            alphas <- numeric(0) # No alphas for StMAR if only one StMAR component
           }
         }
         pars0 <- cbind(pars0, pars)
         alphas0 <- c(alphas0, alphas)
       }
       return(c(as.vector(pars0), alphas0, dfs))
-    } else { # If restricted==TRUE & model == "G-StMAR"
+    } else { # If restricted == TRUE & model == "G-StMAR"
       phi00 <- numeric(0)
       sigmas0 <- numeric(0)
       alphas0 <- numeric(0)
